#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 witherable
version:              0.4.2
visibility:           public
id:                   witherable-0.4.2-AzFzY9Fs5mFFM8hWRv1qOS
key:                  witherable-0.4.2-AzFzY9Fs5mFFM8hWRv1qOS
license:              BSD-3-Clause
copyright:            Copyright (c) 2014 Fumiaki Kinoshita
maintainer:           Fumiaki Kinoshita <fumiexcel@gmail.com>
author:               Fumiaki Kinoshita
homepage:             https://github.com/fumieval/witherable
synopsis:             filterable traversable
description:
    A stronger variant of `traverse` which can remove elements and generalised mapMaybe, catMaybes, filter

category:             Data
abi:                  d3b3db9985bdd451b803052086715f27
exposed:              True
exposed-modules:      Data.Witherable Witherable
import-dirs:          /usr/lib/ghc-9.6.6/site-local/witherable-0.4.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/witherable-0.4.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/witherable-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-witherable
hs-libraries:         HSwitherable-0.4.2-AzFzY9Fs5mFFM8hWRv1qOS
depends:
    base-4.18.2.1 base-orphans-0.9.3-81aawvenzvz3UDj9uhzgjt
    containers-0.6.7 hashable-1.4.7.0-29C6HO1kEzxKGOntKCwjk4
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    indexed-traversable-instances-0.1.2.1-1AMbZrq77RHAmxfC1aK59K
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-Hsa9d2Ja6XgAATZt7ZTK9f
    vector-0.13.2.0-CQhR7DRX3H037jPZymXmiQ

haddock-interfaces:   /usr/share/doc/haskell-witherable/html/witherable.haddock
haddock-html:         /usr/share/doc/haskell-witherable/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

